@@ -3,7 +3,8 @@ package MojoX::CustomTemplateFileParser;
 use strict;
 use warnings;
 use 5.10.1;
-our $VERSION = '0.10';
+our $VERSION = '0.1001'; # VERSION
+# ABSTRACT: Parses a custom Mojo template file format (deprecated)
 
 use Moose;
 with 'MooseX::Object::Pluggable';
@@ -231,15 +232,35 @@ sub _get_baseurl {
 }
 
 1;
+
 __END__
 
-=encoding utf-8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-MojoX::CustomTemplateFileParser - Parses a custom Mojo template file format
+MojoX::CustomTemplateFileParser - Parses a custom Mojo template file format (deprecated)
 
-=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-mojox-customtemplatefileparser"><img src="https://travis-ci.org/Csson/p5-mojox-customtemplatefileparser.svg?branch=master">&nbsp;</a>
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.14-brightgreen.svg" alt="Requires Perl 5.14" /> <a href="https://travis-ci.org/Csson/p5-mojox-customtemplatefileparser"><img src="https://api.travis-ci.org/Csson/p5-mojox-customtemplatefileparser.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.14](https://img.shields.io/badge/perl-5.14-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-mojox-customtemplatefileparser.svg?branch=master)](https://travis-ci.org/Csson/p5-mojox-customtemplatefileparser)
+
+=end markdown
+
+=head1 VERSION
+
+Version 0.1001, released 2015-11-26.
 
 =head1 SYNOPSIS
 
@@ -253,7 +274,7 @@ MojoX::CustomTemplateFileParser - Parses a custom Mojo template file format
 
 =head1 STATUS
 
-Unstable.
+Deprecated. Replaced by L<Stenciller>.
 
 =head1 DESCRIPTION
 
@@ -283,11 +304,17 @@ Currently available plugins:
 
 =over 4
 
-=item * L<MojoX::CustomTemplateFileParser::To::Html>
+=item *
 
-=item * L<MojoX::CustomTemplateFileParser::To::Pod>
+L<MojoX::CustomTemplateFileParser::To::Html>
 
-=item * L<MojoX::CustomTemplateFileParser::To::Test>
+=item *
+
+L<MojoX::CustomTemplateFileParser::To::Pod>
+
+=item *
+
+L<MojoX::CustomTemplateFileParser::To::Test>
 
 =back
 
@@ -295,23 +322,33 @@ Currently available plugins:
 
 =over 4
 
-=item * L<Dist::Zilla::Plugin::Test::CreateFromMojoTemplates>
+=item *
 
-=item * L<Dist::Zilla::Plugin::InsertExample::FromMojoTemplates>
+L<Dist::Zilla::Plugin::Test::CreateFromMojoTemplates>
+
+=item *
+
+L<Dist::Zilla::Plugin::InsertExample::FromMojoTemplates>
 
 =back
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-mojox-customtemplatefileparser>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/MojoX-CustomTemplateFileParser>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014- Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
