@@ -3,7 +3,9 @@ package MojoX::CustomTemplateFileParser::Plugin::To::Test;
 use strict;
 use warnings;
 use 5.10.1;
-our $VERSION = '0.10';
+
+our $VERSION = '0.1001'; # VERSION
+# ABSTRACT: Create tests
 
 use Moose::Role;
 
@@ -50,12 +52,20 @@ sub to_test {
 
 1;
 
-=encoding utf-8
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 MojoX::CustomTemplateFileParser::Plugin::To::Test - Create tests
 
+=head1 VERSION
+
+Version 0.1001, released 2015-11-26.
+
 =head1 SYNOPSIS
 
   use MojoX::CustomTemplateFileParser;
@@ -78,25 +88,37 @@ It returns a string ready to be put in a L<Test::More> file.
 
 =over 4
 
-=item * L<Dist::Zilla::Plugin::Test::CreateFromMojoTemplates>
+=item *
 
-=item * L<MojoX::CustomTemplateFileParser::Plugin::To::Html>
+L<Dist::Zilla::Plugin::Test::CreateFromMojoTemplates>
 
-=item * L<MojoX::CustomTemplateFileParser::Plugin::To::Pod>
+=item *
+
+L<MojoX::CustomTemplateFileParser::Plugin::To::Html>
+
+=item *
+
+L<MojoX::CustomTemplateFileParser::Plugin::To::Pod>
 
 =back
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-mojox-customtemplatefileparser>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/MojoX-CustomTemplateFileParser>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014- Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
